@@ -361,12 +361,12 @@ public class AudioPlayer extends PlaybackServiceFragment implements PlaybackServ
             break;
         default:
         case PlaybackService.REPEAT_ALL:
-            mRepeat.setImageResource(UiTools.getResourceFromAttribute(act, R.attr.ic_repeat_on));
+            mRepeat.setImageResource(UiTools.getResourceFromAttribute(act, R.attr.ic_repeat_all));
             mRepeat.setContentDescription(getResources().getString(R.string.repeat_all));
             break;
         }
 
-        mShuffle.setVisibility(mService.getMediaListSize() > 2 ? View.VISIBLE : View.INVISIBLE);
+        mShuffle.setVisibility(mService.canShuffle() ? View.VISIBLE : View.INVISIBLE);
         mTimeline.setOnSeekBarChangeListener(mTimelineListner);
 
         if (playlistDiffer())
@@ -537,6 +537,8 @@ public class AudioPlayer extends PlaybackServiceFragment implements PlaybackServ
     }
 
     public void showAdvancedOptions(View v) {
+        if (!isResumed())
+            return;
         FragmentManager fm = getActivity().getSupportFragmentManager();
         AdvOptionsDialog advOptionsDialog = new AdvOptionsDialog();
         Bundle args = new Bundle();
