@@ -80,10 +80,10 @@ public class PlaylistAdapter extends RecyclerView.Adapter<PlaylistAdapter.ViewHo
 
     @Override
     public void onBindViewHolder(ViewHolder holder, int position) {
-        Context ctx = holder.itemView.getContext();
+        final Context ctx = holder.itemView.getContext();
         final MediaWrapper media = getItem(position);
         holder.binding.setMedia(media);
-        holder.binding.setSubTitle(MediaUtils.getMediaSubtitle(ctx, media));
+        holder.binding.setSubTitle(MediaUtils.getMediaSubtitle(media));
         holder.binding.setTitleColor(mCurrentIndex == position
                 ? UiTools.getColorFromAttribute(ctx, R.attr.list_title_last)
                 : UiTools.getColorFromAttribute(ctx, R.attr.list_title));
